==> core_plugin-0.1.2.tar.gz: lib/checkout/checkout_model.dart <==
class CheckoutDataModel{
  CheckoutModel data;

  CheckoutDataModel({this.data});
  
  factory CheckoutDataModel.fromJson(Map<String, dynamic> parsedJson) {
    return CheckoutDataModel(
        data: CheckoutModel.fromJson(parsedJson['data']));
  }
}
class CheckoutModel {
  CustomerInfo customerData;
  List<ShopInfo> shopInfos;

  CheckoutModel({this.customerData, this.shopInfos});

  factory CheckoutModel.fromJson(Map<String, dynamic> parsedJson) {
    var list = parsedJson['shop_info'] as List;
    List<ShopInfo> shopInfoList = list.map((i) => ShopInfo.fromJson(i)).toList();
    return CheckoutModel(
        customerData: CustomerInfo.fromJson(parsedJson['customer_data']),
        shopInfos: shopInfoList);
  }

}

class CustomerInfo {
 final CustomerData customerData;
  BadBuyerInfo badBuyerInfo;

  CustomerInfo({this.customerData, this.badBuyerInfo});

  factory CustomerInfo.fromJson(Map<String, dynamic> parsedJson) {
    return CustomerInfo(
      badBuyerInfo: BadBuyerInfo.fromJson(parsedJson['bad_buyer_info']),
        customerData: CustomerData.fromJson(parsedJson['customer_data']));
  }
}

class CustomerData {
   final String customerId;
   final String fptId;
   final String telephone;
   final String firstName;
   final String lastName;
   final String email;
   final String isOtpPhone;
CustomerData({this.customerId, this.fptId, this.telephone, this.firstName, this.lastName, this.email, this.isOtpPhone});

 factory CustomerData.fromJson(Map<String, dynamic> json){

        return CustomerData(
        customerId: json['customer_id'],
        fptId: json['fpt_id'],
        telephone: json['telephone'],
        firstName: json['firstname'],
        lastName: json['lastname'],
        email: json['email'],
        isOtpPhone: json['is_otp_phone']);
  }
}

class BadBuyerInfo {
  final bool shopBlock;

  final bool blockCod;

  final bool otpCod;

  BadBuyerInfo({this.shopBlock, this.blockCod, this.otpCod});

        factory BadBuyerInfo.fromJson(Map<String, dynamic> json){
          return BadBuyerInfo(blockCod: json['shop_block'], otpCod: json['otp_cod'], shopBlock: json['shop_block']);
        }

}

class CustomerAddress {
  final String customerId;
  final String fptId;
  final String createdAt;
  final String addressId;
  final String firstName;
  final String lastName;
  final String city;
  final String cityId;
  final String district;
  final String districtId;
  final String ward;
  final String wardId;
  final String street;
  final String telephone;
  final String email;
  final String latitude;
  final String longitude;
  final String fullAddress;
  final bool isDefaultShipping;

  CustomerAddress.fromJson(Map<String, dynamic> json)
      : customerId = json['customer_id'].toString(),
        fptId = json['fpt_id'].toString(),
        createdAt = json['created_at'].toString(),
        addressId = json['address_id'].toString(),
        firstName = json['firstname'].toString(),
        lastName = json['lastname'].toString(),
        city = json['city'].toString(),
        cityId = json['city_id'].toString(),
        district = json['district'].toString(),
        districtId = json['district_id'].toString(),
        ward = json['ward'].toString(),
        wardId = json['ward_id'].toString(),
        street = json['street'].toString(),
        telephone = json['telephone'].toString(),
        email = json['email'].toString(),
        latitude = json['latitude'].toString(),
        longitude = json['longitude'].toString(),
        fullAddress = json['full_address'].toString(),
        isDefaultShipping = json['is_default_shipping'];
}

class ShopInfo {
   final String shopId;
   final String externalId;
   final String name;
   final String shopType;
  final  bool canUseSuperFastDelivery;

ShopInfo({this.shopId, this.externalId, this.name, this.shopType, this.canUseSuperFastDelivery});

  factory ShopInfo.fromJson(Map<String, dynamic> json){

    return ShopInfo(
    shopId:json['shop_id'],
    externalId: json['external_id'],
    name: json['name'],
    shopType: json['shop_type'],
    canUseSuperFastDelivery: json['can_use_super_fast_delivery']);
  }
}

==> core_plugin-0.1.4.tar.gz: lib/checkout/checkout_model.dart <==
class CheckoutDataModel{
  CheckoutModel data;

  CheckoutDataModel({this.data});
  
  factory CheckoutDataModel.fromJson(Map<String, dynamic> parsedJson) {
    return CheckoutDataModel(
        data: CheckoutModel.fromJson(parsedJson['data']));
  }
}
class CheckoutModel {
  CustomerInfo customerData;
  List<ShopInfo> shopInfos;

  CheckoutModel({this.customerData, this.shopInfos});

  factory CheckoutModel.fromJson(Map<String, dynamic> parsedJson) {
    var list = parsedJson['shop_info'] as List;
    List<ShopInfo> shopInfoList = list.map((i) => ShopInfo.fromJson(i)).toList();
    return CheckoutModel(
        customerData: CustomerInfo.fromJson(parsedJson['customer_data']),
        shopInfos: shopInfoList);
  }

}

class CustomerInfo {
 final CustomerData customerData;
  BadBuyerInfo badBuyerInfo;

  CustomerInfo({this.customerData, this.badBuyerInfo});

  factory CustomerInfo.fromJson(Map<String, dynamic> parsedJson) {
    return CustomerInfo(
      badBuyerInfo: BadBuyerInfo.fromJson(parsedJson['bad_buyer_info']),
        customerData: CustomerData.fromJson(parsedJson['customer_data']));
  }
}

class CustomerData {
   final String customerId;
   final String fptId;
   final String telephone;
   final String firstName;
   final String lastName;
   final String email;
   final String isOtpPhone;
CustomerData({this.customerId, this.fptId, this.telephone, this.firstName, this.lastName, this.email, this.isOtpPhone});

 factory CustomerData.fromJson(Map<String, dynamic> json){

        return CustomerData(
        customerId: json['customer_id'],
        fptId: json['fpt_id'],
        telephone: json['telephone'],
        firstName: json['firstname'],
        lastName: json['lastname'],
        email: json['email'],
        isOtpPhone: json['is_otp_phone']);
  }
}

class BadBuyerInfo {
  final bool shopBlock;

  final bool blockCod;

  final bool otpCod;

  BadBuyerInfo({this.shopBlock = false, this.blockCod = false, this.otpCod = false});

  factory BadBuyerInfo.fromJson(Map<String, dynamic> json){
    return BadBuyerInfo(blockCod: json['block_cod'] ?? false, otpCod: json['otp_cod'] ?? false, shopBlock: json['shop_block'] ?? false);
  }

}

class CustomerAddress {
  final String customerId;
  final String fptId;
  final String createdAt;
  final String addressId;
  final String firstName;
  final String lastName;
  final String city;
  final String cityId;
  final String district;
  final String districtId;
  final String ward;
  final String wardId;
  final String street;
  final String telephone;
  final String email;
  final String latitude;
  final String longitude;
  final String fullAddress;
  final bool isDefaultShipping;

  CustomerAddress.fromJson(Map<String, dynamic> json)
      : customerId = json['customer_id'].toString(),
        fptId = json['fpt_id'].toString(),
        createdAt = json['created_at'].toString(),
        addressId = json['address_id'].toString(),
        firstName = json['firstname'].toString(),
        lastName = json['lastname'].toString(),
        city = json['city'].toString(),
        cityId = json['city_id'].toString(),
        district = json['district'].toString(),
        districtId = json['district_id'].toString(),
        ward = json['ward'].toString(),
        wardId = json['ward_id'].toString(),
        street = json['street'].toString(),
        telephone = json['telephone'].toString(),
        email = json['email'].toString(),
        latitude = json['latitude'].toString(),
        longitude = json['longitude'].toString(),
        fullAddress = json['full_address'].toString(),
        isDefaultShipping = json['is_default_shipping'];
}

class ShopInfo {
   final String shopId;
   final String externalId;
   final String name;
   final String shopType;
  final  bool canUseSuperFastDelivery;

ShopInfo({this.shopId, this.externalId, this.name, this.shopType, this.canUseSuperFastDelivery});

  factory ShopInfo.fromJson(Map<String, dynamic> json){

    return ShopInfo(
    shopId:json['shop_id'],
    externalId: json['external_id'],
    name: json['name'],
    shopType: json['shop_type'],
    canUseSuperFastDelivery: json['can_use_super_fast_delivery']);
  }
}
